import javax.swing.*;
import java.awt.BorderLayout;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;

/**
 * Set up the window and show four buttons and a label.
 * The size of the window is determined from the size of the label.
 * Three of the four buttons are given a "listener", an instance of the new class ButtonHandler.
 * The "west" button doesn't do anything, because it doesn't have a listener.
 * New feature: instead of having ButtonHandler be a named inner class, it has become an "anonymous inner class"
 * defined at each point that it's going to be used.  The advantage of this is that what HAPPENS when the
 * button is pressed is easily visible near where the button is defined.
 * In this example, all three buttons do something very similar, so there's duplicated code; version 13
 * would probably be a better program structure.  However, if the buttons each do something very different,
 * it often makes sense to use anonymous inner classes in this way.
 * @version 14, 3 Feb 2005.
 **/
public class SetUpOperation implements Runnable
{
    JLabel centerText = new JLabel ("some text in the center");

    public void run () {
        // Make sure we have nice window decorations.
        JFrame.setDefaultLookAndFeelDecorated(true);
        
        // Create the window and set its size.
        JFrame frame = new JFrame ("My example program");
        
        // Make sure the program exits when the window is closed.
        frame.setDefaultCloseOperation (JFrame.EXIT_ON_CLOSE);
        
        // Add something to the window.
        JButton northButton = new JButton ("north");
        JButton southButton = new JButton ("south");
        JButton eastButton = new JButton ("east");
        JButton westButton = new JButton ("west");
        frame.getContentPane().add(northButton, BorderLayout.NORTH);
        frame.getContentPane().add(centerText, BorderLayout.CENTER);
        frame.getContentPane().add(eastButton, BorderLayout.EAST);
        frame.getContentPane().add(southButton, BorderLayout.SOUTH);
        frame.getContentPane().add(westButton, BorderLayout.WEST);
        
        northButton.addActionListener (new ActionListener () {
            public void actionPerformed (ActionEvent e) {
                centerText.setText ("Top button pressed!");
            }});
        southButton.addActionListener (new ActionListener () {
            public void actionPerformed (ActionEvent e) {
                centerText.setText ("Bottom button pressed!");
            }});
        eastButton.addActionListener (new ActionListener () {
            public void actionPerformed (ActionEvent e) {
                centerText.setText ("Right-hand button pressed!");
            }});
        // Let's leave westButton without a listener for now.
        
        // Compute the size of the window, just big enough to hold the labels.
        frame.pack();
        
        // Show the window.
        frame.setVisible(true);
    }
}